@@ -1,11 +1,11 @@
-from eremaea import views
 from django.conf.urls import url, include
-from rest_framework import routers
+from eremaea import views
+from rest_framework.routers import DefaultRouter
 
-router = routers.SimpleRouter()
+router = DefaultRouter()
 router.register(r'collections', views.CollectionViewSet)
 router.register(r'snapshots', views.SnapshotViewSet)
-router.register(r'retention_policies', views.RetentionPolicyViewSet, base_name='retention_policy')
+router.register(r'retention_policies', views.RetentionPolicyViewSet, basename='retention_policy')
 
 urlpatterns = [
 	url(r'^', include(router.urls)),
